@@ -623,7 +623,7 @@ class ExecutionServer(BaseServer):
             return
         if len(self.reservation_update_queue) == 0:
             return
-        LOGGER.critical("Sending reservation queue. Current length is %s" % (
+        LOGGER.debug("Sending reservation queue. Current length is %s" % (
             len(self.reservation_update_queue)))
         reservation_updates = self.reservation_update_queue[0:25]
         replace=["reservation_next_request", "reservation_cache"]
